==> mybatis-plus-core-1.0.3-sources.jar: top/doudou/mybatis/plus/config/MybatisPlusConfig.java <==
package top.doudou.mybatis.plus.config;

import com.baomidou.mybatisplus.core.parser.ISqlParser;
import com.baomidou.mybatisplus.extension.parsers.BlockAttackSqlParser;
import com.baomidou.mybatisplus.extension.plugins.OptimisticLockerInterceptor;
import com.baomidou.mybatisplus.extension.plugins.PaginationInterceptor;
import com.baomidou.mybatisplus.extension.plugins.SqlExplainInterceptor;
import com.baomidou.mybatisplus.extension.plugins.pagination.optimize.JsqlParserCountOptimize;
import com.baomidou.mybatisplus.extension.plugins.tenant.TenantHandler;
import com.baomidou.mybatisplus.extension.plugins.tenant.TenantSqlParser;
import lombok.extern.slf4j.Slf4j;
import net.sf.jsqlparser.expression.Expression;
import net.sf.jsqlparser.expression.LongValue;
import org.apache.ibatis.binding.MapperProxyFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import top.doudou.mybatis.plus.context.TenantContextHolder;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description mybatis配置类
 * @Author 傻男人 <244191347@qq.com>
 * @Date 2020-10-15 11:17
 * @Version V1.0
 */
@Slf4j
@Configuration
@ConditionalOnClass(MapperProxyFactory.class)
public class MybatisPlusConfig {

    @Bean
    public PaginationInterceptor paginationInterceptor() {
//        PaginationInterceptor.setDialectType
        PaginationInterceptor paginationInterceptor = new PaginationInterceptor();
        ////设置方言类型
//        paginationInterceptor.setDialectType("mysql");
        // 设置请求的页面大于最大页后操作， true调回到首页，false 继续请求  默认false
        paginationInterceptor.setOverflow(false);
        // 设置最大单页限制数量，默认 500 条，-1 不受限制
        paginationInterceptor.setLimit(200);
        // 开启 count 的 join 优化,只针对部分 left join
        paginationInterceptor.setCountSqlParser(new JsqlParserCountOptimize(true));

        List<ISqlParser> sqlParserList = new ArrayList<>();
        // 攻击 SQL 阻断解析器、加入解析链
        sqlParserList.add(new BlockAttackSqlParser());
//        sqlParserList.add(tenantSqlParser());
//        sqlParserList.add(organizationSqlParser());
        paginationInterceptor.setSqlParserList(sqlParserList);
//        paginationInterceptor.setSqlParserFilter(new SqlParserFilter());
        paginationInterceptor.setSqlParserList(sqlParserList);
        return paginationInterceptor;
    }

    /**
     * 执行分析插件
     * @return
     */
    @Bean
    @Profile({"dev","test"})
    public SqlExplainInterceptor sqlExplainInterceptor(){
        SqlExplainInterceptor sqlExplainInterceptor = new SqlExplainInterceptor();
        return sqlExplainInterceptor;
    }


    /**
     * 乐观锁插件
     * @return
     */
    @Bean
    public OptimisticLockerInterceptor optimisticLockerInterceptor(){
        return new OptimisticLockerInterceptor();
    }

    private TenantSqlParser tenantSqlParser(){
        TenantSqlParser tenantSqlParser = new TenantSqlParser();
        tenantSqlParser.setTenantHandler(new TenantHandler() {
            @Override
            public Expression getTenantId(boolean select) {
                Long tenantId = TenantContextHolder.getTenantId();
                log.info("tenantId:"+tenantId);
                return new LongValue(tenantId);
            }

            @Override
            public String getTenantIdColumn() {
                return "tenant_id";
            }

            @Override
            public boolean doTableFilter(String tableName) {
                return false;
            }
        });
        return tenantSqlParser;
    }

    private TenantSqlParser organizationSqlParser(){
        TenantSqlParser tenantSqlParser = new TenantSqlParser();
        tenantSqlParser.setTenantHandler(new TenantHandler() {
            @Override
            public Expression getTenantId(boolean select) {
                log.info("-------------select-----------:"+select);
                return new LongValue(TenantContextHolder.getOrganizationId());
            }

            @Override
            public String getTenantIdColumn() {
                return "organization_id";
            }

            @Override
            public boolean doTableFilter(String tableName) {
                return false;
            }
        });
        return tenantSqlParser;
    }


}

==> mybatis-plus-core-1.1.0-sources.jar: top/doudou/mybatis/plus/config/MybatisPlusConfig.java <==
package top.doudou.mybatis.plus.config;

import com.baomidou.mybatisplus.annotation.DbType;
import com.baomidou.mybatisplus.core.parser.ISqlParser;
import com.baomidou.mybatisplus.extension.parsers.BlockAttackSqlParser;
import com.baomidou.mybatisplus.extension.plugins.OptimisticLockerInterceptor;
import com.baomidou.mybatisplus.extension.plugins.PaginationInterceptor;
import com.baomidou.mybatisplus.extension.plugins.SqlExplainInterceptor;
import com.baomidou.mybatisplus.extension.plugins.pagination.optimize.JsqlParserCountOptimize;
import com.baomidou.mybatisplus.extension.plugins.tenant.TenantHandler;
import com.baomidou.mybatisplus.extension.plugins.tenant.TenantSqlParser;
import lombok.extern.slf4j.Slf4j;
import net.sf.jsqlparser.expression.Expression;
import net.sf.jsqlparser.expression.LongValue;
import org.apache.ibatis.binding.MapperProxyFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import top.doudou.mybatis.plus.context.TenantContextHolder;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description mybatis配置类
 * @Author 傻男人 <244191347@qq.com>
 * @Date 2020-10-15 11:17
 * @Version V1.0
 */
@Slf4j
@Configuration
@ConditionalOnClass(MapperProxyFactory.class)
public class MybatisPlusConfig {

    @Bean
    public PaginationInterceptor paginationInterceptor() {
        PaginationInterceptor paginationInterceptor = new PaginationInterceptor();
        ////设置方言类型
        paginationInterceptor.setDialectType(DbType.MYSQL.getDb());
        // 设置请求的页面大于最大页后操作， true调回到首页，false 继续请求  默认false
        paginationInterceptor.setOverflow(false);
        // 设置最大单页限制数量，默认 500 条，-1 不受限制
        paginationInterceptor.setLimit(500);
        // 开启 count 的 join 优化,只针对部分 left join
        paginationInterceptor.setCountSqlParser(new JsqlParserCountOptimize(true));

        List<ISqlParser> sqlParserList = new ArrayList<>();
        // 攻击 SQL 阻断解析器、加入解析链
        sqlParserList.add(new BlockAttackSqlParser());
//        sqlParserList.add(tenantSqlParser());
//        sqlParserList.add(organizationSqlParser());
        paginationInterceptor.setSqlParserList(sqlParserList);
//        paginationInterceptor.setSqlParserFilter(new SqlParserFilter());
        return paginationInterceptor;
    }

    /**
     * 执行分析插件
     * @return
     */
    @Bean
    @Profile({"dev","test"})
    public SqlExplainInterceptor sqlExplainInterceptor(){
        SqlExplainInterceptor sqlExplainInterceptor = new SqlExplainInterceptor();
        return sqlExplainInterceptor;
    }

    /**
     * 乐观锁插件
     * @return
     */
    @Bean
    public OptimisticLockerInterceptor optimisticLockerInterceptor(){
        return new OptimisticLockerInterceptor();
    }

//    /**
//     * 注册乐观锁和分页插件
//     * @return
//     * @since 3.4.0
//     */
//    @Bean
//    public MybatisPlusInterceptor mybatisPlusInterceptor(){
//        MybatisPlusInterceptor interceptor = new MybatisPlusInterceptor();
//        interceptor.addInnerInterceptor(new OptimisticLockerInnerInterceptor()); // 乐观锁插件
//        // DbType：数据库类型(根据类型获取应使用的分页方言)
//        interceptor.addInnerInterceptor(new PaginationInnerInterceptor(DbType.MYSQL)); // 分页插件
//        return interceptor;
//    }

    private TenantSqlParser tenantSqlParser(){
        TenantSqlParser tenantSqlParser = new TenantSqlParser();
        tenantSqlParser.setTenantHandler(new TenantHandler() {
            @Override
            public Expression getTenantId(boolean select) {
                Long tenantId = TenantContextHolder.getTenantId();
                log.info("tenantId:"+tenantId);
                return new LongValue(tenantId);
            }

            @Override
            public String getTenantIdColumn() {
                return "tenant_id";
            }

            @Override
            public boolean doTableFilter(String tableName) {
                return false;
            }
        });
        return tenantSqlParser;
    }

    private TenantSqlParser organizationSqlParser(){
        TenantSqlParser tenantSqlParser = new TenantSqlParser();
        tenantSqlParser.setTenantHandler(new TenantHandler() {
            @Override
            public Expression getTenantId(boolean select) {
                log.info("-------------select-----------:"+select);
                return new LongValue(TenantContextHolder.getOrganizationId());
            }

            @Override
            public String getTenantIdColumn() {
                return "organization_id";
            }

            @Override
            public boolean doTableFilter(String tableName) {
                return false;
            }
        });
        return tenantSqlParser;
    }


}
